@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 """Tinyscript package information.
 
@@ -6,8 +5,10 @@
 import os
 
 __author__    = "Alexandre D'Hondt"
+__email__     = "alexandre.dhondt@gmail.com"
 __copyright__ = "© 2017-2020 A. D'Hondt"
-__license__   = "AGPLv3 (http://www.gnu.org/licenses/agpl.html)"
+__license__   = "agpl-3.0"
 
 with open(os.path.join(os.path.dirname(__file__), "VERSION.txt")) as f:
     __version__ = f.read().strip()
+
