@@ -14,13 +14,14 @@ __all__ = __features__ = []
 
 
 # various object type check functions
-__all__ += ["is_bool", "is_dict", "is_int", "is_list", "is_neg_int", "is_pos_int"]
+__all__ += ["is_bool", "is_dict", "is_int", "is_list", "is_neg_int", "is_pos_int", "is_prime"]
 is_bool      = lambda b: isinstance(b, bool)
 is_dict      = lambda d: isinstance(d, dict)
 is_int       = lambda i: isinstance(i, integer_types)
 is_list      = lambda l: isinstance(l, (list, set, tuple))
 is_neg_int   = lambda i, zero=False: is_int(i) and (i <= 0 if zero else i < 0)
 is_pos_int   = lambda i, zero=True: is_int(i) and (i >= 0 if zero else i > 0)
+is_prime     = lambda i: __prime_number(i)
 
 __all__ += ["is_class", "is_coroutine", "is_coroutinefunc", "is_frame", "is_function", "is_generator",
             "is_generatorfunc", "is_instance", "is_iterable", "is_lambda", "is_method", "is_module", "is_type"]
@@ -41,7 +42,7 @@ is_type          = lambda t: isinstance(t, type)
 
 # -------------------- DATA FORMAT ARGUMENT TYPES --------------------
 __all__ += ["neg_int", "negative_int", "pos_int", "positive_int", "ints", "neg_ints", "negative_ints", "pos_ints",
-            "positive_ints"]
+            "positive_ints", "prime_number"]
 
 
 def __ints(l, check_func=lambda x: False, idescr=None, **kwargs):
@@ -57,3 +58,33 @@ negative_int = neg_int = lambda i, zero=False: __ints(i, is_neg_int, "negative",
 positive_int = pos_int = lambda i, zero=True: __ints(i, is_pos_int, "positive", zero=zero)[0]
 negative_ints = neg_ints = lambda l, zero=False: __ints(l, is_neg_int, "negative", zero=zero)
 positive_ints = pos_ints = lambda l, zero=True: __ints(l, is_pos_int, "positive", zero=zero)
+
+
+# see: https://stackoverflow.com/questions/15285534/isprime-function-for-python-language
+def __prime_number(n, fail=False):
+    """ Determines if a number is a prime. """
+    try:
+        i = int(n)
+        if i != n:
+            raise ValueError
+    except:
+        if fail:
+            raise ValueError("Not a prime number")
+        return False
+    if i in [2, 3, 5, 7]:
+        return i if fail else True
+    if i < 2 or i % 2 == 0 or i % 3 == 0:
+        if fail:
+            raise ValueError("Not a prime number")
+        return False
+    # all primes > 3 are of the form: 6n +/- 1 ; so, start with f = 5 and test f, f+2 for being prime then loop by 6. 
+    f, r = 5, int(i ** .5)
+    while f <= r:
+        if i % f == 0 or i % (f + 2) == 0:
+            if fail:
+                raise ValueError("Not a prime number")
+            return False
+        f += 6
+    return i if fail else True
+prime_number = lambda n: __prime_number(n, True)
+
