@@ -13,18 +13,13 @@ from inspect import currentframe, getmembers, isfunction, ismethod
 from os.path import basename, splitext
 from six import string_types
 
+from .features.handlers import _hooks
 from .argreparse import *
-from .timing import set_time_items
-from .handlers import *
-from .helpers.constants import LINUX, PYTHON3
+from .features import *
+from .helpers.common import is_admin
+from .helpers.constants import LINUX, PYTHON3, WINDOWS
 from .helpers.data.types import ip_address, port_number
 from .helpers.text import configure_docformat, gt
-from .interact import set_interact_items
-from .hotkeys import set_hotkeys
-from .notify import set_notify_items
-from .progress import set_progress_items
-from .loglib import *
-from .step import set_step_items
 
 
 __all__ = __features__ = ["parser", "initialize", "validate"]
@@ -96,8 +91,7 @@ def initialize(add_banner=False,
     # handle backward-compatibility arguments
     exit_at_interrupt = kwargs.pop('exit_at_interrupt', None)
     if len(kwargs) > 0:
-        raise TypeError("Unexpected keyword-argument{} ({})"
-                        .format(["", "s"][len(kwargs) > 1], ", ".join(kwargs.keys())))
+        raise TypeError("Unexpected keyword-arguments (%s)" % ", ".join(kwargs.keys()))
     # get caller's frame
     frame = currentframe().f_back
     # walk the stack until a frame containing a known object is found
@@ -255,15 +249,15 @@ def initialize(add_banner=False,
             glob['logger'].error(gt("Bad report generation function"))
         else:
             # lazily import report features
-            #  -> reason: they rely on pandas and weasyprint, which take time to be imported ; so, when report features
-            #              are not used in a script, report classes won't be loaded
+            #  -> reason: they rely on weasyprint, which take time to be imported ; so, when report features are not
+            #              used in a script, report classes won't be loaded
             all_list = __import__("tinyscript.report", fromlist=['__all__']).__all__
             report = __import__("tinyscript.report", fromlist=all_list)
             for f in all_list:
                 glob[f] = globals()[f] = getattr(report, f)
             # now populate the parser with report-related arguments
             r = p.add_argument_group("report arguments")
-            output_func = list(filter(lambda x: not x[0].startswith('_'), getmembers(Report, predicate=isfunction)))
+            output_func = list(filter(lambda x: getattr(x[1], '_output', False), getmembers(Report)))
             choices = list(map(lambda x: x[0], output_func))
             if r.add_argument("--output", choices=choices, default="pdf", last=True, prefix="report",
                               help=gt("report output format")):
@@ -274,7 +268,7 @@ def initialize(add_banner=False,
                 r.add_argument("--filename", last=True, prefix="report", help=gt("report filename"))
     elif report_func is not None and not PYTHON3:
         report_func = None  # disable reporting in the at_exit handler
-        glob['logger'].warning(gt("Report generation is only for Python 3"))
+        glob['logger'].warning(gt("Report generation is only available with Python 3"))
     # extended logging features
     if ext_logging:
         i.add_argument("-f", "--logfile", last=True, help=gt("destination log file"))
@@ -286,10 +280,9 @@ def initialize(add_banner=False,
     # now parse inputs
     glob['args'], glob['parser'] = p.parse_args(), p
     # 3) if sudo required, restart the script
-    if sudo:
-        # if not root, restart the script in another process and jump to this
-        if os.geteuid() != 0:
-            os.execvp("sudo", ["sudo", sys.executable] + sys.argv)
+    if sudo and not is_admin():
+        exe = ["runas", "/env", "/user:Administrator"] if WINDOWS else ["sudo", "-E"]
+        os.execvp(["sudo", "runas"][WINDOWS], exe + [sys.executable] + sys.argv)
     # 4) configure logging and get the main logger
     configure_logger(glob, multi_level_debug, glob['args']._collisions.get("relative"),
                      glob['args']._collisions.get("logfile"), glob['args']._collisions.get("syslog"))
@@ -409,3 +402,4 @@ class ProxyArgumentParser(object):
 
 
 parser = ProxyArgumentParser()
+
