@@ -8,13 +8,20 @@ try:  # will work in Python 3
     from importlib import reload
     import configparser
 except ImportError:  # will fail in Python 2 ; it will keep the built-in reload
-    reload = reload
+    reload = reload  # this declaration is required to get "reload" in the global scope for inclusion in __all__
     import ConfigParser as configparser
 
 from .codep import code
+from .ftools import functools
 from .hash import hashlib
 from .inspectp import inspect
+from .itools import itertools
 from .log import logging
+from .pswd import getpass
+from .rand import random
+from .regex import re
+from .shutilp import shutil
+from .stringp import string
 from .venv import virtualenv, PipPackage, VirtualEnv
 
 
@@ -25,9 +32,16 @@ __imports__ = {
     'bad': [],
     'enhanced': [
         "code",
+        "functools",
+        "getpass",
         "hashlib",
         "inspect",
+        "itertools",
         "logging",
+        "random",
+        "re",
+        "shutil",
+        "string",
         "virtualenv",
     ],
     'standard': [
@@ -37,15 +51,12 @@ __imports__ = {
         "binascii",
         "codecs",
         "collections",
+        "colorful",
         "configparser",
         "ctypes",
         "fileinput",
-        "itertools",
         "os",
         "platform",
-        "random",
-        "re",
-        "shutil",
         "signal",
         "string",
         "struct",
@@ -53,12 +64,12 @@ __imports__ = {
         "sys",
         "time",
         "types",
+        "uuid",
     ],
     'optional': [
         "bs4",
         "fs",
-        "numpy",
-        "pandas",
+        "loremipsum",
         "requests",
     ]
 }
@@ -105,3 +116,4 @@ def load(module, optional=False):
 
 
 _load_preimports()
+
